*************
Helpful Links
*************

We hope to curate in the ``climpred`` documentation a comprehensive report of terminology, best
practices, analysis methods, etc. in the prediction community. Here we suggest other resources for
initialized prediction of the Earth system to round out the information provided in our
documentation.

Forecast Verification
#####################

* `CAWCR Forecast Verification Overview <https://www.cawcr.gov.au/projects/verification/>`_:
  A nice overview of forecast verification, including a suite of metrics and their derivation.
